Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Text
Imports System.Windows.Forms

Public Partial Class Form1
	Inherits Form
	Private bIsConnected As Boolean = False
	Private sdk As Ingressus.Ingressus = Nothing
	Private monitorTimer As New Timer()

	Public Sub New()
		Try
			InitializeComponent()
			SetIngressusConnectorControl(True)
			EnableBtnConnector(False)

			monitorTimer.Interval = 5000
			' every 5sec pull data 
			AddHandler monitorTimer.Tick, New EventHandler(AddressOf monitorTimer_Tick)
		Catch
		End Try
	End Sub

	Protected Sub ShowCurrentStatus(msg As String)
		Try
			If txtCurrentStatus.Text.Length >= txtCurrentStatus.MaxLength Then
				txtCurrentStatus.Text = String.Empty
			End If

			txtCurrentStatus.Text += msg & vbCr & vbLf
			txtCurrentStatus.SelectionStart = txtCurrentStatus.Text.Length
			txtCurrentStatus.ScrollToCaret()

			System.Windows.Forms.Application.DoEvents()
		Catch ex As Exception
			txtCurrentStatus.Text += ex.Message
		End Try
	End Sub

	Protected Function IsDeviceConnected() As Boolean
		If bIsConnected Then
			Return True
		Else
			ShowCurrentStatus("Please connect Ingresuss")
			Return False
		End If
	End Function

    Private Sub btnClear_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnClear.Click
        txtCurrentStatus.Text = String.Empty
        System.Windows.Forms.Application.DoEvents()
    End Sub

	#Region "Real Time"
    Private Sub btnStartMonitor_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnStartMonitor.Click
        EnableMonitor(True)
    End Sub

    Private Sub btnStopMonitor_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnStopMonitor.Click
        EnableMonitor(False)
    End Sub

	Protected Sub EnableMonitor(isStart As Boolean)
		If IsDeviceConnected() Then
			monitorTimer.Enabled = isStart
			btnStopMonitor.Enabled = isStart
			btnStartMonitor.Enabled = Not isStart

			If isStart Then
				ShowCurrentStatus("Start monitoring...")
				ShowCurrentStatus("Datetime,Param1,Param2,Param3,Param4,Param5,Param6")
			Else
				ShowCurrentStatus("Stop monitoring...")
			End If
		End If
	End Sub

	Private Sub monitorTimer_Tick(sender As Object, e As EventArgs)
		Try
			If sdk.ReadRealTimeLog() Then
				Dim datetime As String = String.Empty
				Dim param1 As String = String.Empty
				Dim param2 As String = String.Empty
				Dim param3 As String = String.Empty
				Dim param4 As String = String.Empty
				Dim param5 As String = String.Empty
				Dim param6 As String = String.Empty

				While sdk.GetRealTimeLog(datetime, param1, param2, param3, param4, param5, _
					param6)
					ShowCurrentStatus(datetime & "," & param1 & "," & param2 & "," & param3 & "," & param4 & "," & param5 & "," & param6)
				End While
			End If
		Catch ex As Exception
			ShowCurrentStatus(ex.Message)
		End Try
	End Sub

	#End Region

	#Region "Ingressus Connector"
    Private Sub rbTCP_Click(ByVal sender As Object, ByVal e As EventArgs) Handles rbTCP.Click
        SetIngressusConnectorControl(True)
    End Sub

    Private Sub rbCOM_Click(ByVal sender As Object, ByVal e As EventArgs) Handles rbCOM.Click
        SetIngressusConnectorControl(False)
    End Sub

	Protected Sub SetIngressusConnectorControl(isTCP As Boolean)
		txtBaudrate.Visible = Not isTCP
		txtComPort.Visible = Not isTCP
		txtIP.Visible = isTCP
		txtPort.Visible = isTCP

		lblIP.Visible = isTCP
		lblPort.Visible = isTCP
		lblComPort.Visible = Not isTCP
		lblBaudrate.Visible = Not isTCP
	End Sub

    Private Sub btnConnect_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnConnect.Click
        Try
            sdk = New Ingressus.Ingressus()

            Dim iTimeout As Integer = Convert.ToInt32(txtTimeout.Text.Trim())
            sdk.SetConnectionTimeout(iTimeout)
            ' in seconds 
            sdk.SetCommKey(txtCommKey.Text.Trim())

            If rbTCP.Checked Then
                Dim port As Integer = Convert.ToInt32(txtPort.Text.Trim())

                If sdk.Connect_TCPIP(txtIP.Text.Trim(), port) Then
                    EnableBtnConnector(True)
                    ShowCurrentStatus("Successfully connect device")
                    ShowDeviceInfo()
                Else
                    EnableBtnConnector(False)
                    ShowCurrentStatus("Failed to connect Ingressus")
                End If
            Else
                Dim comPort As Integer = Convert.ToInt32(txtComPort.Text.Trim())
                Dim baudrate As Integer = Convert.ToInt32(txtBaudrate.Text.Trim())
                Dim deviceID As Integer = Convert.ToInt32(txtDeviceID.Text.Trim())

                If sdk.Connect_COMM(comPort, baudrate, deviceID) Then
                    EnableBtnConnector(True)
                    ShowCurrentStatus("Successfully connect device")
                    ShowDeviceInfo()
                Else
                    EnableBtnConnector(False)
                    ShowCurrentStatus("Failed to connect Ingressus")
                End If
            End If
        Catch ex As Exception
            EnableBtnConnector(False)
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

	Protected Sub ShowDeviceInfo()
        ShowCurrentStatus("Serial Num. : " & sdk.SerialNum)
        ShowCurrentStatus("Model : " & sdk.ProductCode)
		ShowCurrentStatus("MAC Address : " & sdk.MACAddress)
		ShowCurrentStatus("Firware Version : " & sdk.FirmwareVersion)
		ShowCurrentStatus("FP Algvr : " & sdk.FPAlgvr)
		ShowCurrentStatus("Door Count : " & sdk.DoorCount)
		ShowCurrentStatus("AuxIn Count : " & sdk.AuxInCount)
		ShowCurrentStatus("AuxOut Count : " & sdk.AuxOutCount)
		ShowCurrentStatus("Reader Count : " & sdk.ReaderCount)

	End Sub

    Private Sub btnDisconnect_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDisconnect.Click
        Try
            If sdk.Disconnect() Then
                ' remember disconnect to release resources
                EnableBtnConnector(False)
                ShowCurrentStatus("Successfully disconnect.")
            Else
                EnableBtnConnector(True)
                ShowCurrentStatus("Failed to disconnect.")
            End If
        Catch ex As Exception
            EnableBtnConnector(False)
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

	Protected Sub EnableBtnConnector(enable As Boolean)
		If enable Then
			txtCurrentStatus.Text = String.Empty
		End If

		bIsConnected = enable
		btnConnect.Enabled = Not enable
		btnDisconnect.Enabled = enable

		System.Windows.Forms.Application.DoEvents()
	End Sub
	#End Region

	' 
'         *  P/S :
'         *  Demo is set table data One by One
'         *  You may write all data to buffer, then only use function WriteAllDataToDevice() upload to Ingressus.
'         *  
'         


	#Region "User"
    Private Sub btnGetAllUser_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetAllUser.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadAllDeviceData(clsConst.TableName_Display_User) Then
                    Dim userid As Integer = 0
                    Dim privilege As Integer = 0
                    Dim username As String = String.Empty
                    Dim cardnum As String = String.Empty
                    Dim multicard As Integer = 0
                    Dim password As String = String.Empty
                    Dim issuetime As String = String.Empty
                    Dim expiretime As String = String.Empty

                    ShowCurrentStatus(clsConst.TableName_User_Col)
                    '"UserID,Privilege,Username,CardNum,MulticardGroup,Password,IssueTime,ExpireTime";

                    While sdk.GetUserInfo(userid, privilege, username, cardnum, multicard, password, _
                     issuetime, expiretime)
                        ShowCurrentStatus(userid & "," & privilege & "," & username & "," & cardnum & "," & multicard & "," & password & "," & issuetime & "," & expiretime)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnGetUser_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetUser.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadDeviceData(clsConst.TableName_Display_User, txtUserID.Text.Trim()) Then
                    Dim userid As Integer = 0
                    Dim privilege As Integer = 0
                    Dim username As String = String.Empty
                    Dim cardnum As String = String.Empty
                    Dim multicard As Integer = 0
                    Dim password As String = String.Empty
                    Dim issuetime As String = String.Empty
                    Dim expiretime As String = String.Empty

                    ShowCurrentStatus(clsConst.TableName_User_Col)
                    '"UserID,Privilege,Username,CardNum,MulticardGroup,Password,IssueTime,ExpireTime";

                    While sdk.GetUserInfo(userid, privilege, username, cardnum, multicard, password, _
                     issuetime, expiretime)
                        ShowCurrentStatus(userid & "," & privilege & "," & username & "," & cardnum & "," & multicard & "," & password & "," & issuetime & "," & expiretime)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSetUser_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetUser.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadDeviceData(clsConst.TableName_Display_User, txtUserID.Text.Trim()) Then
                    Dim userid As Integer = Convert.ToInt32(txtUserID.Text.Trim())
                    Dim privilege As Integer = Convert.ToInt32(txtPrivilege.Text.Trim())
                    Dim username As String = txtUserName.Text.Trim()
                    Dim cardnum As String = txtCardNum.Text.Trim()
                    Dim multicard As Integer = Convert.ToInt32(txtMulticardGroup.Text.Trim())
                    Dim password As String = txtPassword.Text.Trim()
                    Dim issuetime As String = Convert.ToDateTime(txtStartTime.Text.Trim()).ToString("yyyyMMdd")
                    Dim expiretime As String = Convert.ToDateTime(txtExpireTime.Text.Trim()).ToString("yyyyMMdd")


                    sdk.SetUserInfo(userid, privilege, username, cardnum, multicard, password, _
                     issuetime, expiretime)
                    If sdk.WriteAllDataToDevice() Then
                        ' upload user to Ingresuss  
                        ShowCurrentStatus("Successfully upload user")
                    Else
                        ShowCurrentStatus("Failed to upload user")
                    End If
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDelUser_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDelUser.Click
        Try
            If IsDeviceConnected() Then
                Dim userid As Integer = Convert.ToInt32(txtUserID.Text.Trim())
                If sdk.DeleteUserInfo(userid) Then
                    ShowCurrentStatus("Successfully delete userid=" & userid)
                Else
                    ShowCurrentStatus("Failed to delete userid=" & userid)
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDelAllUser_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDelAllUser.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ClearUserInfo() Then
                    ShowCurrentStatus("Successfully clear user info")
                Else
                    ShowCurrentStatus("Failed to clear user info")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

	#End Region

	#Region "User Access Level"
    Private Sub btnGetAL_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetAL.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadDeviceData(clsConst.TableName_Display_UserAccessLevel, txtALUser.Text.Trim()) Then
                    Dim userid As Integer = 0
                    Dim timezoneid As Integer = 0
                    Dim doorid As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_UserAccessLevel_Col)
                    '"UserID,AuthorizeTimezoneId,AuthorizeDoorId";

                    While sdk.GetUserAccessLevel(userid, timezoneid, doorid)
                        ShowCurrentStatus(userid & "," & timezoneid & "," & doorid)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSetUserAL_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetUserAL.Click
        Try
            If IsDeviceConnected() Then
                Dim userid As Integer = Convert.ToInt32(txtALUser.Text.Trim())
                Dim timezoneid As Integer = Convert.ToInt32(txtALTimezone.Text.Trim())
                Dim doorid As Integer = Convert.ToInt32(txtALDoor.Text.Trim())

                sdk.SetUserAccessLevel(userid, timezoneid, doorid)
                If sdk.WriteAllDataToDevice() Then
                    ShowCurrentStatus("Successfully upload user access level")
                Else
                    ShowCurrentStatus("Failed to upload user access level")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDeleteUserAL_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDeleteUserAL.Click
        Try
            If IsDeviceConnected() Then
                Dim userid As Integer = Convert.ToInt32(txtALUser.Text.Trim())
                If sdk.DeleteUserAccessLevel(userid) Then
                    ShowCurrentStatus("Successfully delete user access level")
                Else
                    ShowCurrentStatus("Failed to delete user access level")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnGetAllAL_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetAllAL.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadAllDeviceData(clsConst.TableName_Display_UserAccessLevel) Then
                    Dim userid As Integer = 0
                    Dim timezoneid As Integer = 0
                    Dim doorid As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_UserAccessLevel_Col)
                    '"UserID,AuthorizeTimezoneId,AuthorizeDoorId";

                    While sdk.GetUserAccessLevel(userid, timezoneid, doorid)
                        ShowCurrentStatus(userid & "," & timezoneid & "," & doorid)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDeleteAllAL_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDeleteAllAL.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ClearUserAccessLevel() Then
                    ShowCurrentStatus("Successfully delete all user access level")
                Else
                    ShowCurrentStatus("Failed to delete all user access level")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub
	#End Region

	#Region "Holiday"
    Private Sub btnGetHoliday_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetHoliday.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadDeviceData(clsConst.TableName_Display_Holiday, txtHoliday.Text.Trim()) Then
                    Dim holiday As String = String.Empty
                    Dim holidaytype As Integer = 0
                    Dim [loop] As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_Holiday_Col)
                    '"Holiday,HolidayType,Loop";

                    While sdk.GetHolidayData(holiday, holidaytype, [loop])
                        ShowCurrentStatus(holiday & "," & holidaytype & "," & [loop])
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSetHoliday_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetHoliday.Click
        Try
            If IsDeviceConnected() Then
                Dim holiday As String = txtHoliday.Text.Trim()
                Dim holidaytype As Integer = Convert.ToInt32(txtHolidayType.Text.Trim())
                Dim [loop] As Integer = Convert.ToInt32(txtLoop.Text.Trim())

                sdk.SetHolidayData(holiday, holidaytype, [loop])
                If sdk.WriteAllDataToDevice() Then
                    ShowCurrentStatus("Successfully upload holiday")
                Else
                    ShowCurrentStatus("Failed to upload holiday")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDeleteHoliday_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDeleteHoliday.Click
        Try
            If IsDeviceConnected() Then
                Dim holiday As String = txtHoliday.Text.Trim()
                If sdk.DeleteHolidayData(holiday) Then
                    ShowCurrentStatus("Successfully delete holiday")
                Else
                    ShowCurrentStatus("Failed to delete holiday")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnGetAllHoliday_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetAllHoliday.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadAllDeviceData(clsConst.TableName_Display_Holiday) Then
                    Dim holiday As String = String.Empty
                    Dim holidaytype As Integer = 0
                    Dim [loop] As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_Holiday_Col)
                    '"Holiday,HolidayType,Loop";

                    While sdk.GetHolidayData(holiday, holidaytype, [loop])
                        ShowCurrentStatus(holiday & "," & holidaytype & "," & [loop])
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDelAllHoliday_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDelAllHoliday.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ClearHolidayData() Then
                    ShowCurrentStatus("Successfully delete all holiday")
                Else
                    ShowCurrentStatus("Failed to delete all holiday")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub
	#End Region

	#Region "Timezone"
    Private Sub btnGetTimezone_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetTimezone.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadDeviceData(clsConst.TableName_Display_TimeZone, txtTimezoneID.Text.Trim()) Then
                    Dim TimezoneId As Integer = 0
                    Dim SunTime1 As Long = 0
                    Dim SunTime2 As Long = 0
                    Dim SunTime3 As Long = 0
                    Dim MonTime1 As Long = 0
                    Dim MonTime2 As Long = 0
                    Dim MonTime3 As Long = 0
                    Dim TueTime1 As Long = 0
                    Dim TueTime2 As Long = 0
                    Dim TueTime3 As Long = 0
                    Dim WedTime1 As Long = 0
                    Dim WedTime2 As Long = 0
                    Dim WedTime3 As Long = 0
                    Dim ThuTime1 As Long = 0
                    Dim ThuTime2 As Long = 0
                    Dim ThuTime3 As Long = 0
                    Dim FriTime1 As Long = 0
                    Dim FriTime2 As Long = 0
                    Dim FriTime3 As Long = 0
                    Dim SatTime1 As Long = 0
                    Dim SatTime2 As Long = 0
                    Dim SatTime3 As Long = 0
                    Dim Hol1Time1 As Long = 0
                    Dim Hol1Time2 As Long = 0
                    Dim Hol1Time3 As Long = 0
                    Dim Hol2Time1 As Long = 0
                    Dim Hol2Time2 As Long = 0
                    Dim Hol2Time3 As Long = 0
                    Dim Hol3Time1 As Long = 0
                    Dim Hol3Time2 As Long = 0
                    Dim Hol3Time3 As Long = 0

                    ShowCurrentStatus(clsConst.TableName_TimeZone_Col)
                    '"TimezoneId,SunTime1,SunTime2,SunTime3,MonTime1,MonTime2,MonTime3,TueTime1,TueTime2,TueTime3,WedTime1,WedTime2,WedTime3,ThuTime1,ThuTime2,ThuTime3,FriTime1,FriTime2,FriTime3,SatTime1,SatTime2,SatTime3,Hol1Time1,Hol1Time2,Hol1Time3,Hol2Time1,Hol2Time2,Hol2Time3,Hol3Time1,Hol3Time2,Hol3Time3";

                    While sdk.GetTimezoneData(TimezoneId, SunTime1, SunTime2, SunTime3, MonTime1, MonTime2, _
                     MonTime3, TueTime1, TueTime2, TueTime3, WedTime1, WedTime2, _
                     WedTime3, ThuTime1, ThuTime2, ThuTime3, FriTime1, FriTime2, _
                     FriTime3, SatTime1, SatTime2, SatTime3, Hol1Time1, Hol1Time2, _
                     Hol1Time3, Hol2Time1, Hol2Time2, Hol2Time3, Hol3Time1, Hol3Time2, _
                     Hol3Time3)
                        ShowCurrentStatus(TimezoneId & "," & SunTime1 & "," & SunTime2 & "," & SunTime3 & "," & MonTime1 & "," & MonTime2 & "," & MonTime3 & "," & TueTime1 & "," & TueTime2 & "," & TueTime3 & "," & WedTime1 & "," & WedTime2 & "," & WedTime3 & "," & ThuTime1 & "," & ThuTime2 & "," & ThuTime3 & "," & FriTime1 & "," & FriTime2 & "," & FriTime3 & "," & SatTime1 & "," & SatTime2 & "," & SatTime3 & "," & Hol1Time1 & "," & Hol1Time2 & "," & Hol1Time3 & "," & Hol2Time1 & "," & Hol2Time2 & "," & Hol2Time3 & "," & Hol3Time1 & "," & Hol3Time2 & "," & Hol3Time3)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSetTimezone_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetTimezone.Click
        Try
            If IsDeviceConnected() Then
                Dim TimezoneId As Integer = Convert.ToInt32(txtTimezoneID.Text.Trim())
                Dim SunTime1 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSun1S.Text.Trim() & txtSun1E.Text.Trim())
                ' starttime + endtime, must be 8digits
                Dim SunTime2 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSun2S.Text.Trim() & txtSun2E.Text.Trim())
                Dim SunTime3 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSun3S.Text.Trim() & txtSun3E.Text.Trim())
                Dim MonTime1 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtMon1S.Text.Trim() & txtMon1E.Text.Trim())
                Dim MonTime2 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtMon2S.Text.Trim() & txtMon2E.Text.Trim())
                Dim MonTime3 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtMon3S.Text.Trim() & txtMon3E.Text.Trim())
                Dim TueTime1 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtTue1S.Text.Trim() & txtTue1E.Text.Trim())
                Dim TueTime2 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtTue2S.Text.Trim() & txtTue2E.Text.Trim())
                Dim TueTime3 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtTue3S.Text.Trim() & txtTue3E.Text.Trim())
                Dim WedTime1 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtWed1S.Text.Trim() & txtWed1E.Text.Trim())
                Dim WedTime2 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtWed2S.Text.Trim() & txtWed2E.Text.Trim())
                Dim WedTime3 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtWed3S.Text.Trim() & txtWed3E.Text.Trim())
                Dim ThuTime1 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtThu1S.Text.Trim() & txtThu1E.Text.Trim())
                Dim ThuTime2 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtThu2S.Text.Trim() & txtThu2E.Text.Trim())
                Dim ThuTime3 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtThu3S.Text.Trim() & txtThu3E.Text.Trim())
                Dim FriTime1 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtFri1S.Text.Trim() & txtSun1E.Text.Trim())
                Dim FriTime2 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtFri2S.Text.Trim() & txtFri2E.Text.Trim())
                Dim FriTime3 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtFri3S.Text.Trim() & txtFri3E.Text.Trim())
                Dim SatTime1 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSat1S.Text.Trim() & txtSat1E.Text.Trim())
                Dim SatTime2 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSat2S.Text.Trim() & txtSat2E.Text.Trim())
                Dim SatTime3 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSat3S.Text.Trim() & txtSat3E.Text.Trim())
                Dim Hol1Time1 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol11S.Text.Trim() & txtHol11E.Text.Trim())
                Dim Hol1Time2 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol12S.Text.Trim() & txtHol12E.Text.Trim())
                Dim Hol1Time3 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol13S.Text.Trim() & txtHol13E.Text.Trim())
                Dim Hol2Time1 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol21S.Text.Trim() & txtHol21E.Text.Trim())
                Dim Hol2Time2 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol22S.Text.Trim() & txtHol22E.Text.Trim())
                Dim Hol2Time3 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol23S.Text.Trim() & txtHol23E.Text.Trim())
                Dim Hol3Time1 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol31S.Text.Trim() & txtHol31E.Text.Trim())
                Dim Hol3Time2 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol32S.Text.Trim() & txtHol32E.Text.Trim())
                Dim Hol3Time3 As Long = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol33S.Text.Trim() & txtHol33E.Text.Trim())


                sdk.SetTimezoneData(TimezoneId, SunTime1, SunTime2, SunTime3, MonTime1, MonTime2, _
                 MonTime3, TueTime1, TueTime2, TueTime3, WedTime1, WedTime2, _
                 WedTime3, ThuTime1, ThuTime2, ThuTime3, FriTime1, FriTime2, _
                 FriTime3, SatTime1, SatTime2, SatTime3, Hol1Time1, Hol1Time2, _
                 Hol1Time3, Hol2Time1, Hol2Time2, Hol2Time3, Hol3Time1, Hol3Time2, _
                 Hol3Time3)

                If sdk.WriteAllDataToDevice() Then
                    ShowCurrentStatus("Successfully upload timezone")
                Else
                    ShowCurrentStatus("Failed to upload timezone")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDeleteTimezone_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDeleteTimezone.Click
        Try
            If IsDeviceConnected() Then
                Dim TimezoneId As Integer = Convert.ToInt32(txtTimezoneID.Text.Trim())

                If sdk.DeleteTimezoneData(TimezoneId) Then
                    ShowCurrentStatus("Successfully delete timezone")
                Else
                    ShowCurrentStatus("Failed to delete timezone")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnGetAllTimezone_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetAllTimezone.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadAllDeviceData(clsConst.TableName_Display_TimeZone) Then

                    Dim TimezoneId As Integer = 0
                    Dim SunTime1 As Long = 0
                    Dim SunTime2 As Long = 0
                    Dim SunTime3 As Long = 0
                    Dim MonTime1 As Long = 0
                    Dim MonTime2 As Long = 0
                    Dim MonTime3 As Long = 0
                    Dim TueTime1 As Long = 0
                    Dim TueTime2 As Long = 0
                    Dim TueTime3 As Long = 0
                    Dim WedTime1 As Long = 0
                    Dim WedTime2 As Long = 0
                    Dim WedTime3 As Long = 0
                    Dim ThuTime1 As Long = 0
                    Dim ThuTime2 As Long = 0
                    Dim ThuTime3 As Long = 0
                    Dim FriTime1 As Long = 0
                    Dim FriTime2 As Long = 0
                    Dim FriTime3 As Long = 0
                    Dim SatTime1 As Long = 0
                    Dim SatTime2 As Long = 0
                    Dim SatTime3 As Long = 0
                    Dim Hol1Time1 As Long = 0
                    Dim Hol1Time2 As Long = 0
                    Dim Hol1Time3 As Long = 0
                    Dim Hol2Time1 As Long = 0
                    Dim Hol2Time2 As Long = 0
                    Dim Hol2Time3 As Long = 0
                    Dim Hol3Time1 As Long = 0
                    Dim Hol3Time2 As Long = 0
                    Dim Hol3Time3 As Long = 0

                    ShowCurrentStatus(clsConst.TableName_TimeZone_Col)

                    While sdk.GetTimezoneData(TimezoneId, SunTime1, SunTime2, SunTime3, MonTime1, MonTime2, _
                     MonTime3, TueTime1, TueTime2, TueTime3, WedTime1, WedTime2, _
                     WedTime3, ThuTime1, ThuTime2, ThuTime3, FriTime1, FriTime2, _
                     FriTime3, SatTime1, SatTime2, SatTime3, Hol1Time1, Hol1Time2, _
                     Hol1Time3, Hol2Time1, Hol2Time2, Hol2Time3, Hol3Time1, Hol3Time2, _
                     Hol3Time3)
                        ShowCurrentStatus(TimezoneId & "," & SunTime1 & "," & SunTime2 & "," & SunTime3 & "," & MonTime1 & "," & MonTime2 & "," & MonTime3 & "," & TueTime1 & "," & TueTime2 & "," & TueTime3 & "," & WedTime1 & "," & WedTime2 & "," & WedTime3 & "," & ThuTime1 & "," & ThuTime2 & "," & ThuTime3 & "," & FriTime1 & "," & FriTime2 & "," & FriTime3 & "," & SatTime1 & "," & SatTime2 & "," & SatTime3 & "," & Hol1Time1 & "," & Hol1Time2 & "," & Hol1Time3 & "," & Hol2Time1 & "," & Hol2Time2 & "," & Hol2Time3 & "," & Hol3Time1 & "," & Hol3Time2 & "," & Hol3Time3)
                    End While
                Else
                    ShowCurrentStatus("No record found")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDeleteAllTimezone_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDeleteAllTimezone.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ClearTimezoneData() Then
                    ShowCurrentStatus("Successfully clear all timezone")
                Else
                    ShowCurrentStatus("Failed to clear all timezone")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub
	#End Region

	#Region "General Log"
    Private Sub btnGetGeneral_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetGeneral.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadDeviceData(clsConst.TableName_Display_GeneralLog, txtGUser.Text.Trim()) Then
                    Dim userid As Integer = 0
                    Dim cardNumber As String = String.Empty
                    Dim verified As Integer = 0
                    Dim doorNo As Integer = 0
                    Dim eventType As Integer = 0
                    Dim inOutState As Integer = 0
                    Dim timesec As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_GeneralLog_Col)
                    ' "UserID,Cardno,Verified,DoorNo,EventType,InOutState,Time_second";

                    While sdk.GetUserGeneralLog(userid, cardNumber, verified, doorNo, eventType, inOutState, _
                     timesec)
                        ShowCurrentStatus(userid & "," & cardNumber & "," & verified & "," & doorNo & "," & eventType & "," & inOutState & "," & timesec)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSetGeneral_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetGeneral.Click
        Try
            If IsDeviceConnected() Then
                Dim userid As Integer = Convert.ToInt32(txtGUser.Text.Trim())
                Dim cardNumber As String = txtGCard.Text.Trim()
                Dim verified As Integer = Convert.ToInt32(txtGDoor.Text.Trim())
                Dim doorNo As Integer = Convert.ToInt32(txtGDoor.Text.Trim())
                Dim eventType As Integer = Convert.ToInt32(txtGEvent.Text.Trim())
                Dim inOutState As Integer = Convert.ToInt32(txtGInOut.Text.Trim())


                Dim iYear As Integer = Convert.ToInt32(txtGYear.Text.Trim())
                Dim iMonth As Integer = Convert.ToInt32(txtGMonth.Text.Trim())
                Dim iDay As Integer = Convert.ToInt32(txtGDay.Text.Trim())
                Dim iHour As Integer = Convert.ToInt32(txtGHour.Text.Trim())
                Dim iMinute As Integer = Convert.ToInt32(txtGMinute.Text.Trim())
                Dim iSec As Integer = Convert.ToInt32(txtGSecond.Text.Trim())
                Dim timesec As Integer = ((iYear - 2000) * 12 * 31 + (iMonth - 1) * 31 + (iDay - 1)) * (24 * 60 * 60) + iHour * 60 * 60 + iMinute * 60 + iSec

                sdk.SetUserGeneralLog(userid, cardNumber, verified, doorNo, eventType, inOutState,  timesec)
                If sdk.WriteAllDataToDevice() Then
                    ShowCurrentStatus("Successfully upload general log")
                Else
                    ShowCurrentStatus("Failed to upload general log")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDeleteGeneral_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDeleteGeneral.Click
        Try
            If IsDeviceConnected() Then
                Dim userid As Integer = Convert.ToInt32(txtGUser.Text.Trim())
                If sdk.DeleteUserGeneralLog(userid) Then
                    ShowCurrentStatus("Successfully delete general log")
                Else
                    ShowCurrentStatus("Failed to delete general log")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnGetAllGeneral_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetAllGeneral.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadAllDeviceData(clsConst.TableName_Display_GeneralLog) Then
                    Dim userid As Integer = 0
                    Dim cardNumber As String = String.Empty
                    Dim verified As Integer = 0
                    Dim doorNo As Integer = 0
                    Dim eventType As Integer = 0
                    Dim inOutState As Integer = 0
                    Dim timesec As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_GeneralLog_Col)
                    ' "UserID,Cardno,Verified,DoorNo,EventType,InOutState,Time_second";

                    While sdk.GetUserGeneralLog(userid, cardNumber, verified, doorNo, eventType, inOutState,   timesec)
                        ShowCurrentStatus(userid & "," & cardNumber & "," & verified & "," & doorNo & "," & eventType & "," & inOutState & "," & timesec)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDeleteAllGeneral_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDeleteAllGeneral.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ClearUserGeneralLog() Then
                    ShowCurrentStatus("Successfully delete all general log")
                Else
                    ShowCurrentStatus("Failed to delete all general log")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub
	#End Region

	#Region "First Card"
    Private Sub btnGetFirst_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetFirst.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadDeviceData(clsConst.TableName_Display_FirstCard, txtFirstUser.Text.Trim()) Then
                    Dim userid As Integer = 0
                    Dim timezoneid As Integer = 0
                    Dim doorNo As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_FirstCard_Col)
                    '"UserID,DoorNo,TimezoneID";

                    While sdk.GetFirstCardData(userid, doorNo, timezoneid)
                        ShowCurrentStatus(userid & "," & doorNo & "," & timezoneid)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSetFirst_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetFirst.Click
        Try
            If IsDeviceConnected() Then
                Dim userid As Integer = Convert.ToInt32(txtFirstUser.Text.Trim())
                Dim doorNo As Integer = Convert.ToInt32(txtFirstDoor.Text.Trim())
                Dim timezoneid As Integer = Convert.ToInt32(txtFirstTimezone.Text.Trim())

                sdk.SetFirstCardData(userid, doorNo, timezoneid)
                If sdk.WriteAllDataToDevice() Then
                    ShowCurrentStatus("Successfully upload First Card")
                Else
                    ShowCurrentStatus("Failed to upload First Card")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDelFirst_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDelFirst.Click
        Try
            If IsDeviceConnected() Then
                Dim userid As Integer = Convert.ToInt32(txtFirstUser.Text.Trim())

                If sdk.DeleteFirstCardData(userid) Then
                    ShowCurrentStatus("Successfully delete first card user")
                Else
                    ShowCurrentStatus("Failed to delete first card user")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnGetAllFirst_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetAllFirst.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadAllDeviceData(clsConst.TableName_Display_FirstCard) Then
                    Dim userid As Integer = 0
                    Dim timezoneid As Integer = 0
                    Dim doorNo As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_FirstCard_Col)
                    '"UserID,DoorNo,TimezoneID";

                    While sdk.GetFirstCardData(userid, doorNo, timezoneid)
                        ShowCurrentStatus(userid & "," & doorNo & "," & timezoneid)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDelAllFirst_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDelAllFirst.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ClearFirstCardData() Then
                    ShowCurrentStatus("Successfully delete all first card user")
                Else
                    ShowCurrentStatus("Failed to delete all first card user")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

	#End Region

	#Region "Multicard"
    Private Sub btnGetMulti_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetMulti.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadDeviceData(clsConst.TableName_Display_MultiCard, txtMIndex.Text.Trim()) Then
                    Dim index As Integer = 0
                    Dim doorNo As Integer = 0
                    Dim g1 As Integer = 0
                    Dim g2 As Integer = 0
                    Dim g3 As Integer = 0
                    Dim g4 As Integer = 0
                    Dim g5 As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_MultiCard_Col)
                    ' "Index,DoorId,Group1,Group2,Group3,Group4,Group5";

                    While sdk.GetMultiCardData(index, doorNo, g1, g2, g3, g4,  g5)
                        ShowCurrentStatus(index & "," & doorNo & "," & g1 & "," & g2 & "," & g3 & "," & g4 & "," & g5)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSetMulti_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetMulti.Click
        Try
            If IsDeviceConnected() Then
                Dim index As Integer = Convert.ToInt32(txtMIndex.Text.Trim())
                Dim doorNo As Integer = Convert.ToInt32(txtMDoor.Text.Trim())
                Dim g1 As Integer = Convert.ToInt32(txtMP1.Text.Trim())
                Dim g2 As Integer = Convert.ToInt32(txtMP2.Text.Trim())
                Dim g3 As Integer = Convert.ToInt32(txtMP3.Text.Trim())
                Dim g4 As Integer = Convert.ToInt32(txtMP4.Text.Trim())
                Dim g5 As Integer = Convert.ToInt32(txtMP5.Text.Trim())

                sdk.SetMultiCardData(index, doorNo, g1, g2, g3, g4,  g5)
                If sdk.WriteAllDataToDevice() Then
                    ShowCurrentStatus("Successfully upload multicard")
                Else
                    ShowCurrentStatus("Failed to upload multicard")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDeleteMulti_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDeleteMulti.Click
        Try
            If IsDeviceConnected() Then
                Dim index As Integer = Convert.ToInt32(txtMIndex.Text.Trim())

                If sdk.DeleteMultiCardData(index) Then
                    ShowCurrentStatus("Successfully delete multicard")
                Else
                    ShowCurrentStatus("Failed to delete multicard")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnGetAllMulti_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetAllMulti.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadAllDeviceData(clsConst.TableName_Display_MultiCard) Then
                    Dim index As Integer = 0
                    Dim doorNo As Integer = 0
                    Dim g1 As Integer = 0
                    Dim g2 As Integer = 0
                    Dim g3 As Integer = 0
                    Dim g4 As Integer = 0
                    Dim g5 As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_MultiCard_Col)
                    ' "Index,DoorId,Group1,Group2,Group3,Group4,Group5";

                    While sdk.GetMultiCardData(index, doorNo, g1, g2, g3, g4, g5)
                        ShowCurrentStatus(index & "," & doorNo & "," & g1 & "," & g2 & "," & g3 & "," & g4 & "," & g5)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDelAllMulti_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDelAllMulti.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ClearMultiCardData() Then
                    ShowCurrentStatus("Successfully delete all multicard")
                Else
                    ShowCurrentStatus("Failed to delete all multicard")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub
	#End Region

	#Region "Fire Alarm"
    Private Sub btnGetLinkage_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetLinkage.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadDeviceData(clsConst.TableName_Display_FireAlarm, txtLinkageIndex.Text.Trim()) Then
                    Dim index As Integer = 0
                    Dim eventType As Integer = 0
                    Dim InAddr As Integer = 0
                    Dim OutType As Integer = 0
                    Dim OutAddr As Integer = 0
                    Dim OutTime As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_FireAlarm_Col)
                    '"Index,EventType,InAddr,OutType,OutAddr,OutTime";

                    While sdk.GetFireAlarmData(index, eventType, InAddr, OutType, OutAddr, OutTime)
                        ShowCurrentStatus(index & "," & eventType & "," & InAddr & "," & OutType & "," & OutAddr & "," & OutTime)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSetLinkage_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetLinkage.Click
        Try
            If IsDeviceConnected() Then
                Dim index As Integer = Convert.ToInt32(txtLinkageIndex.Text.Trim())
                Dim eventType As Integer = Convert.ToInt32(txtLinkageEvent.Text.Trim())
                Dim InAddr As Integer = Convert.ToInt32(txtLinkageInAdd.Text.Trim())
                Dim OutType As Integer = Convert.ToInt32(txtLinkageOutType.Text.Trim())
                Dim OutAddr As Integer = Convert.ToInt32(txtLinkageOutAdd.Text.Trim())
                Dim OutTime As Integer = Convert.ToInt32(txtLinkageOutTime.Text.Trim())

                sdk.SetFireAlarmData(index, eventType, InAddr, OutType, OutAddr, OutTime)
                If sdk.WriteAllDataToDevice() Then
                    ShowCurrentStatus("Successfully upload fire alarm")
                Else
                    ShowCurrentStatus("Failed to upload fire alarm")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDelLinkage_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDelLinkage.Click
        Try
            If IsDeviceConnected() Then
                Dim index As Integer = Convert.ToInt32(txtLinkageIndex.Text.Trim())

                If sdk.DeleteFireAlarmData(index) Then
                    ShowCurrentStatus("Successfully delete fire alarm")
                Else
                    ShowCurrentStatus("Failed to delete fire alarm")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnGetAllLinkage_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetAllLinkage.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadAllDeviceData(clsConst.TableName_Display_FireAlarm) Then
                    Dim index As Integer = 0
                    Dim eventType As Integer = 0
                    Dim InAddr As Integer = 0
                    Dim OutType As Integer = 0
                    Dim OutAddr As Integer = 0
                    Dim OutTime As Integer = 0

                    ShowCurrentStatus(clsConst.TableName_FireAlarm_Col)
                    '"Index,EventType,InAddr,OutType,OutAddr,OutTime";

                    While sdk.GetFireAlarmData(index, eventType, InAddr, OutType, OutAddr, OutTime)
                        ShowCurrentStatus(index & "," & eventType & "," & InAddr & "," & OutType & "," & OutAddr & "," & OutTime)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDelAllLinkage_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDelAllLinkage.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ClearFireAlarmData() Then
                    ShowCurrentStatus("Successfully delete all fire alarm")
                Else
                    ShowCurrentStatus("Failed to delete all fire alarm")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub
	#End Region

	#Region "Template"
    Private Sub btnGetTemp_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetTemp.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadDeviceData(clsConst.TableName_Display_Template, txtTemplateUser.Text.Trim()) Then
                    Dim userid As Integer = 0
                    Dim fingerid As Integer = 0
                    Dim valid As Integer = 0
                    Dim template As String = String.Empty

                    ShowCurrentStatus(clsConst.TableName_Template_Col)
                    ' "UserID,FingerID,Valid,Template";

                    While sdk.GetUserTemplate(userid, fingerid, valid, template)
                        ShowCurrentStatus(userid & "," & fingerid & "," & valid & "," & template)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSetTemp_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetTemp.Click
        Try
            If IsDeviceConnected() Then
                Dim userid As Integer = Convert.ToInt32(txtTemplateUser.Text.Trim())
                Dim fingerid As Integer = Convert.ToInt32(txtTemplateFinger.Text.Trim())
                Dim valid As Integer = Convert.ToInt32(txtTempValid.Text.Trim())
                Dim template As String = txtTemplate.Text.Trim()

                sdk.SetUserTemplate(userid, fingerid, valid, template)
                If sdk.WriteAllDataToDevice() Then
                    ShowCurrentStatus("Successfully upload user template")
                Else
                    ShowCurrentStatus("Failed to upload user template")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDelTemp_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDelTemp.Click
        Try
            If IsDeviceConnected() Then
                Dim userid As Integer = Convert.ToInt32(txtTemplateUser.Text.Trim())

                If sdk.DeleteUserTemplate(userid) Then
                    ShowCurrentStatus("Successfully delete user template")
                Else
                    ShowCurrentStatus("Failed to delete user template")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnGetAllTemp_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnGetAllTemp.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ReadAllDeviceData(clsConst.TableName_Display_Template) Then
                    Dim userid As Integer = 0
                    Dim fingerid As Integer = 0
                    Dim valid As Integer = 0
                    Dim template As String = String.Empty

                    ShowCurrentStatus(clsConst.TableName_Template_Col)
                    ' "UserID,FingerID,Valid,Template";

                    While sdk.GetUserTemplate(userid, fingerid, valid, template)
                        ShowCurrentStatus(userid & "," & fingerid & "," & valid & "," & template)
                    End While
                Else
                    ShowCurrentStatus("No record found.")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDelAllTemp_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDelAllTemp.Click
        Try
            If IsDeviceConnected() Then
                If sdk.ClearUserTemplate() Then
                    ShowCurrentStatus("Successfully delete all user template")
                Else
                    ShowCurrentStatus("Failed to delete all user template")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub
	#End Region

	#Region "Scan Device"
	Private listDevice As New List(Of ObjDevice)()
    Private Sub btnScanDevice_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnScanDevice.Click
        Try
            Me.Cursor = Cursors.WaitCursor
            Using sdkScan As New Ingressus.Ingressus()
                ' after scan, dispose the object
                ShowCurrentStatus("Scanning network...")

                If sdkScan.ScanDevice() Then
                    Dim mac As String = String.Empty
                    Dim serialNo As String = String.Empty
                    Dim ip As String = String.Empty
                    Dim gateway As String = String.Empty
                    Dim subnet As String = String.Empty
                    Dim firmVer As String = String.Empty
                    Dim model As String = String.Empty

                    While sdkScan.GetScanDevice(mac, serialNo, ip, gateway, subnet, firmVer, model)


                        Dim obj As New ObjDevice
                        With obj
                            .MAC = mac
                            .IPAddress = ip
                            .Firmware = firmVer
                            .Gateway = gateway
                            .Model = model
                            .SerialNum = serialNo
                            .Subnet = subnet
                        End With

                        listDevice.Add(obj)
                    End While

                    AddDeviceToDropDownList()
                    ShowCurrentStatus("Successfully scan network")
                Else
                    ShowCurrentStatus("No Ingressus found.")
                End If

                If cboMAC.Items.Count > 0 Then
                    txtNewGateway.Enabled = True
                    txtNewIP.Enabled = True
                    txtNewSubnet.Enabled = True
                    cboMAC.Enabled = True
                    btnChangeDevice.Enabled = True
                Else
                    txtNewGateway.Enabled = False
                    txtNewIP.Enabled = False
                    txtNewSubnet.Enabled = False
                    cboMAC.Enabled = False
                    btnChangeDevice.Enabled = False
                End If
            End Using
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
        Me.Cursor = Cursors.Arrow
    End Sub

	Protected Sub AddDeviceToDropDownList()
		For Each device As ObjDevice In listDevice
			cboMAC.Items.Add(device.MAC & " ( " & device.SerialNum & " )")
		Next
	End Sub

    Private Sub cboMAC_SelectedIndexChanged(ByVal sender As Object, ByVal e As EventArgs) Handles cboMAC.SelectedIndexChanged
        Try
            If cboMAC.SelectedItem IsNot Nothing AndAlso cboMAC.SelectedItem.ToString() <> String.Empty Then
                Dim selectedIngressus As String = cboMAC.SelectedItem.ToString()
                Dim split As String() = selectedIngressus.Split("("c)
                Dim mac As String = split(0).Trim()

                For Each device As ObjDevice In listDevice
                    If device.MAC = mac Then
                        txtNewGateway.Text = device.Gateway
                        txtNewSubnet.Text = device.Subnet
                        txtNewIP.Text = device.IPAddress
                        Exit For
                    End If
                Next
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnChangeDevice_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnChangeDevice.Click
        Try
            If cboMAC.SelectedItem IsNot Nothing AndAlso cboMAC.SelectedItem.ToString() <> String.Empty Then
                Dim selectedIngressus As String = cboMAC.SelectedItem.ToString()
                Dim split As String() = selectedIngressus.Split("("c)
                Dim mac As String = split(0).Trim()

                If Not String.IsNullOrEmpty(mac) Then
                    Using sdkChange As New Ingressus.Ingressus()
                        If sdkChange.ChangeDeviceInfo(mac, txtNewIP.Text.Trim(), txtNewGateway.Text.Trim(), txtNewSubnet.Text.Trim()) Then
                            ShowCurrentStatus("Successfully change device info")
                        Else
                            ShowCurrentStatus("Failed to change device info")
                        End If
                    End Using
                Else
                    ShowCurrentStatus("Failed to change device info")
                End If
            Else
                ShowCurrentStatus("Please select choose a Ingressus")
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub
	#End Region

	#Region "Ingressus Options"
    Private Sub btnSysGet_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSysGet.Click
        Try
            If IsDeviceConnected() Then
                If cboSysP.SelectedItem IsNot Nothing AndAlso cboSysP.SelectedItem.ToString() <> String.Empty Then
                    Dim value As String = sdk.GetSysOptions(cboSysP.SelectedItem.ToString().Trim())
                    txtSysV.Text = value
                    ShowCurrentStatus(cboSysP.SelectedItem.ToString() & "=" & value)
                Else
                    ShowCurrentStatus("Please select a system options")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSysSet_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSysSet.Click
        Try
            If IsDeviceConnected() Then
                If cboSysP.SelectedItem IsNot Nothing AndAlso cboSysP.SelectedItem.ToString() <> String.Empty Then
                    If sdk.SetSysOptions(cboSysP.SelectedItem.ToString().Trim(), txtSysV.Text.Trim()) Then
                        ShowCurrentStatus("Successfully set system options")
                    Else
                        ShowCurrentStatus("Failed to set system options")
                    End If
                Else
                    ShowCurrentStatus("Please select a system options")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDoorGet_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDoorGet.Click
        Try
            If IsDeviceConnected() Then
                If IsDeviceConnected() Then
                    If cboDoorP.SelectedItem IsNot Nothing AndAlso cboDoorP.SelectedItem.ToString() <> String.Empty Then
                        Dim doorNo As Integer = Convert.ToInt32(txtDoorDNo.Text.Trim())
                        Dim value As String = sdk.GetDoorOptions(doorNo, cboDoorP.SelectedItem.ToString().Trim())
                        txtDoorV.Text = value
                        ShowCurrentStatus(cboDoorP.SelectedItem.ToString().Trim() & "=" & value)
                    Else
                        ShowCurrentStatus("Please select a door options")
                    End If
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnDoorSet_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnDoorSet.Click
        Try
            If IsDeviceConnected() Then
                If IsDeviceConnected() Then
                    If cboDoorP.SelectedItem IsNot Nothing AndAlso cboDoorP.SelectedItem.ToString() <> String.Empty Then
                        Dim doorNo As Integer = Convert.ToInt32(txtDoorDNo.Text.Trim())
                        If sdk.SetDoorOptions(doorNo, cboDoorP.SelectedItem.ToString().Trim(), txtDoorV.Text.Trim()) Then
                            ShowCurrentStatus("Successfully set door options")
                        Else
                            ShowCurrentStatus("Failed to set door options")
                        End If
                    Else
                        ShowCurrentStatus("Please select a door options")
                    End If
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnSetLocalTime_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetLocalTime.Click
        If IsDeviceConnected() Then
            If sdk.SetDeviceTimeLocal() Then
                ShowCurrentStatus("Successfully set device date and time")
            Else
                ShowCurrentStatus("Failed to set device date and time")
            End If
        End If
    End Sub

    Private Sub btnSetTime_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnSetTime.Click
        Try
            If IsDeviceConnected() Then
                Dim iYear As Integer = Convert.ToInt32(txtOptYear.Text.Trim())
                Dim iMonth As Integer = Convert.ToInt32(txtOptMonth.Text.Trim())
                Dim iDay As Integer = Convert.ToInt32(txtOptDay.Text.Trim())
                Dim iHour As Integer = Convert.ToInt32(txtOptHour.Text.Trim())
                Dim iMinute As Integer = Convert.ToInt32(txtOptMin.Text.Trim())
                Dim iSec As Integer = Convert.ToInt32(txtOptSec.Text.Trim())

                If sdk.SetDeviceTime(iYear, iMonth, iDay, iHour, iMinute, iSec) Then
                    ShowCurrentStatus("Successfully set device date and time")
                Else
                    ShowCurrentStatus("Failed to set device date and time")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

	#Region "Remote Options"
    Private Sub btnRemoteClose_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnRemoteClose.Click
        Try
            If IsDeviceConnected() Then
                Dim doorNo As Integer = Convert.ToInt32(txtRemoteDoor.Text.Trim())

                If sdk.RemoteCloseDoor(doorNo) Then
                    ShowCurrentStatus("Successfully close door")
                Else
                    ShowCurrentStatus("Failed to open door")
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnRemoteOpen_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnRemoteOpen.Click
        Try
            If IsDeviceConnected() Then
                If IsDeviceConnected() Then
                    Dim doorNo As Integer = Convert.ToInt32(txtRemoteDoor.Text.Trim())

                    If sdk.RemoteOpenDoor(doorNo, 10) Then
                        ShowCurrentStatus("Successfully open door")
                    Else
                        ShowCurrentStatus("Failed to open door")
                    End If
                End If
            End If
        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try
    End Sub

    Private Sub btnRestart_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnRestart.Click
        If IsDeviceConnected() Then
            If sdk.RestartDevice() Then
                ShowCurrentStatus("Successfully restart Ingressus")
            Else
                ShowCurrentStatus("Failed to restart Ingressus")
            End If
        End If
    End Sub

    Private Sub btnOffAlarm_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnOffAlarm.Click
        If IsDeviceConnected() Then
            If sdk.TurnOffAlarm() Then
                ShowCurrentStatus("Successfully turn off alarm")
            Else
                ShowCurrentStatus("Failed to turn off alarm")
            End If
        End If
    End Sub
	#End Region
	#End Region


    Private Sub txtTemplate_KeyDown(ByVal sender As Object, ByVal e As KeyEventArgs) Handles txtTemplate.KeyDown
        Try
            If e.Control AndAlso (e.KeyCode = System.Windows.Forms.Keys.A) Then
                txtTemplate.SelectAll()
                e.SuppressKeyPress = True
                e.Handled = True
            Else
                MyBase.OnKeyDown(e)
            End If
        Catch
        End Try
    End Sub
     
 
    Private Sub Button1_Click(sender As System.Object, e As System.EventArgs) Handles Button1.Click

        Try
            If (IsDeviceConnected()) Then

                Dim deviceTime As String =   sdk.GetSysOptions("DateTime")
                Dim iDeviceTime As Long = Convert.ToInt64(deviceTime)
                Dim Second As Long = iDeviceTime Mod 60
                Dim Minute As Long = (iDeviceTime / 60) Mod 60
                Dim Hour As Long = (iDeviceTime / 3600) Mod 24
                Dim Day As Long = (iDeviceTime / 86400) Mod 31 + 1
                Dim Month As Long = (iDeviceTime / 2678400) Mod 12 + 1
                Dim Year As Long = (iDeviceTime / 32140800) + 2000

                ShowCurrentStatus("Device Current Time : " + Year + "-" + Month + "-" + Day + " " + Hour + ":" + Minute + ":" + Second)
            End If


        Catch ex As Exception
            ShowCurrentStatus(ex.Message)
        End Try 

    End Sub
End Class

Public Class ObjDevice
	Public Property MAC() As String
		Get
			Return m_MAC
		End Get
		Set
			m_MAC = Value
		End Set
	End Property
	Private m_MAC As String
	Public Property SerialNum() As String
		Get
			Return m_SerialNum
		End Get
		Set
			m_SerialNum = Value
		End Set
	End Property
	Private m_SerialNum As String
	Public Property IPAddress() As String
		Get
			Return m_IPAddress
		End Get
		Set
			m_IPAddress = Value
		End Set
	End Property
	Private m_IPAddress As String
	Public Property Gateway() As String
		Get
			Return m_Gateway
		End Get
		Set
			m_Gateway = Value
		End Set
	End Property
	Private m_Gateway As String
	Public Property Subnet() As String
		Get
			Return m_Subnet
		End Get
		Set
			m_Subnet = Value
		End Set
	End Property
	Private m_Subnet As String
	Public Property Firmware() As String
		Get
			Return m_Firmware
		End Get
		Set
			m_Firmware = Value
		End Set
	End Property
	Private m_Firmware As String
	Public Property Model() As String
		Get
			Return m_Model
		End Get
		Set
			m_Model = Value
		End Set
	End Property
	Private m_Model As String
End Class


