﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
 
namespace IngressusDemo
{
    public partial class Form1 : Form
    {
        bool bIsConnected = false;
        Ingressus.Ingressus sdk = null;
        Timer monitorTimer = new Timer();

        public Form1()
        {
            try
            {
                InitializeComponent();
                SetIngressusConnectorControl(true);
                EnableBtnConnector(false);

                monitorTimer.Interval = 5000; // every 5sec pull data 
                monitorTimer.Tick += new EventHandler(monitorTimer_Tick); 
            }
            catch { }
        } 
      
        protected void ShowCurrentStatus(string msg)
        {
            try
            {
                if (txtCurrentStatus.Text.Length >= txtCurrentStatus.MaxLength )
                {
                    txtCurrentStatus.Text = string.Empty;
                }

                txtCurrentStatus.Text += msg + "\r\n";
                txtCurrentStatus.SelectionStart = txtCurrentStatus.Text.Length;
                txtCurrentStatus.ScrollToCaret();
               
                System.Windows.Forms.Application.DoEvents();
            }
            catch (Exception ex) { txtCurrentStatus.Text += ex.Message; }
        }

        protected bool IsDeviceConnected()
        {
            if (bIsConnected)
            {
                return true;
            }
            else
            {
                ShowCurrentStatus("Please connect Ingresuss");
                return false;
            }
        }
      
        private void btnClear_Click(object sender, EventArgs e)
        {
            txtCurrentStatus.Text = string.Empty;
            System.Windows.Forms.Application.DoEvents();
        }  

        #region Real Time 
        private void btnStartMonitor_Click(object sender, EventArgs e)
        {
            EnableMonitor(true);
        }

        private void btnStopMonitor_Click(object sender, EventArgs e)
        {
            EnableMonitor(false);
        }

        protected void EnableMonitor(bool isStart)
        {
            if (IsDeviceConnected())
            {
                monitorTimer.Enabled = isStart;
                btnStopMonitor.Enabled = isStart;
                btnStartMonitor.Enabled = !isStart;

                if (isStart)
                {
                    ShowCurrentStatus("Start monitoring...");
                    ShowCurrentStatus("Datetime,Param1,Param2,Param3,Param4,Param5,Param6");
                }
                else
                {
                    ShowCurrentStatus("Stop monitoring...");
                }
            }
        }

        void monitorTimer_Tick(object sender, EventArgs e)
        {
            try
            {
                if (sdk.ReadRealTimeLog())
                {
                    string datetime = string.Empty;
                    string param1 = string.Empty;
                    string param2 = string.Empty; 
                    string param3 = string.Empty;
                    string param4 = string.Empty;
                    string param5 = string.Empty;
                    string param6 = string.Empty;

                    while (sdk.GetRealTimeLog(out datetime, out param1, out param2, out param3, out param4, out param5, out param6))
                    {
                        ShowCurrentStatus(datetime + "," + param1 + "," + param2 + "," + param3 + "," + param4 + "," + param5+ "," + param6  );
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        #endregion

        #region Ingressus Connector
        private void rbTCP_Click(object sender, EventArgs e)
        {
            SetIngressusConnectorControl(true);
        }

        private void rbCOM_Click(object sender, EventArgs e)
        {
            SetIngressusConnectorControl(false);
        }

        protected void SetIngressusConnectorControl(bool isTCP)
        {
            txtBaudrate.Visible = !isTCP;
            txtComPort.Visible = !isTCP; 
            txtIP.Visible = isTCP;
            txtPort.Visible = isTCP;

            lblIP.Visible = isTCP;
            lblPort.Visible = isTCP;
            lblComPort.Visible = !isTCP;
            lblBaudrate.Visible = !isTCP;  
        }

        private void btnConnect_Click(object sender, EventArgs e)
        {
            try
            {
                sdk = new Ingressus.Ingressus();

                int iTimeout = Convert.ToInt32(txtTimeout.Text.Trim());
                sdk.SetConnectionTimeout(iTimeout); // in seconds 
                sdk.SetCommKey(txtCommKey.Text.Trim()); 
                 
                if (rbTCP.Checked)
                {
                    int port = Convert.ToInt32(txtPort.Text.Trim());

                    if (sdk.Connect_TCPIP(txtIP.Text.Trim(), port))
                    {
                        EnableBtnConnector(true);
                        ShowCurrentStatus("Successfully connect device"); 
                        ShowDeviceInfo();
                    }
                    else
                    {
                        EnableBtnConnector(false);
                        ShowCurrentStatus("Failed to connect Ingressus");
                    }
                }
                else
                {
                    int comPort = Convert.ToInt32(txtComPort.Text.Trim());
                    int baudrate = Convert.ToInt32(txtBaudrate.Text.Trim());
                    int deviceID = Convert.ToInt32(txtDeviceID.Text.Trim());

                    if (sdk.Connect_COMM(comPort, baudrate, deviceID))
                    {
                        EnableBtnConnector(true);
                        ShowCurrentStatus("Successfully connect device");
                        ShowDeviceInfo();
                    }
                    else
                    {
                        EnableBtnConnector(false);
                        ShowCurrentStatus("Failed to connect Ingressus");
                    }
                } 
            }
            catch (Exception ex) { EnableBtnConnector(false); ShowCurrentStatus(ex.Message); }
        }

        protected void ShowDeviceInfo()
        {
            ShowCurrentStatus("Serial Num. : " + sdk.SerialNum); 
            ShowCurrentStatus("Model : " + sdk.ProductCode);
            ShowCurrentStatus("MAC Address : " + sdk.MACAddress );
            ShowCurrentStatus("Firware Version : " + sdk.FirmwareVersion );
            ShowCurrentStatus("FP Algvr : " + sdk.FPAlgvr );
            ShowCurrentStatus("Door Count : " + sdk.DoorCount );
            ShowCurrentStatus("AuxIn Count : " + sdk.AuxInCount);
            ShowCurrentStatus("AuxOut Count : " + sdk.AuxOutCount);
            ShowCurrentStatus("Reader Count : " + sdk.ReaderCount); 
           
        }

        private void btnDisconnect_Click(object sender, EventArgs e)
        {
            try
            {
                if (sdk.Disconnect()) // remember disconnect to release resources
                {
                    EnableBtnConnector(false);
                    ShowCurrentStatus("Successfully disconnect.");
                }
                else
                {
                    EnableBtnConnector(true);
                    ShowCurrentStatus("Failed to disconnect.");
                }
            }
            catch (Exception ex) { EnableBtnConnector(false); ShowCurrentStatus(ex.Message); }
        }

        protected void EnableBtnConnector(bool enable)
        {
            if (enable)
            {
                txtCurrentStatus.Text = string.Empty;  
            } 

            bIsConnected = enable;
            btnConnect.Enabled = !enable;
            btnDisconnect.Enabled = enable;

            System.Windows.Forms.Application.DoEvents();
        }
        #endregion

        /* 
         *  P/S :
         *  Demo is set table data One by One
         *  You may write all data to buffer, then only use function WriteAllDataToDevice() upload to Ingressus.
         *  
         */

        #region User
        private void btnGetAllUser_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                { 
                    if (sdk.ReadAllDeviceData(clsConst.TableName_Display_User))
                    {
                        int userid = 0;
                        int privilege = 0;
                        string username = string.Empty;
                        string cardnum = string.Empty;
                        int multicard = 0;
                        string password = string.Empty;
                        string issuetime = string.Empty;
                        string expiretime = string.Empty;

                        ShowCurrentStatus(clsConst.TableName_User_Col);
                        //"UserID,Privilege,Username,CardNum,MulticardGroup,Password,IssueTime,ExpireTime";

                        while (sdk.GetUserInfo(out userid, out privilege, out username, out cardnum, out multicard, out password, out issuetime, out expiretime))
                        {
                            ShowCurrentStatus(userid + "," + privilege + "," + username + "," + cardnum + "," + multicard + "," + password + "," + issuetime + "," + expiretime);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                } 
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnGetUser_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadDeviceData(clsConst.TableName_Display_User, txtUserID.Text.Trim()))
                    {
                        int userid = 0;
                        int privilege = 0;
                        string username = string.Empty;
                        string cardnum = string.Empty;
                        int multicard = 0;
                        string password = string.Empty;
                        string issuetime = string.Empty;
                        string expiretime = string.Empty;

                        ShowCurrentStatus(clsConst.TableName_User_Col);
                        //"UserID,Privilege,Username,CardNum,MulticardGroup,Password,IssueTime,ExpireTime";

                        while (sdk.GetUserInfo(out userid, out privilege, out username, out cardnum, out multicard, out password, out issuetime, out expiretime))
                        {
                            ShowCurrentStatus(userid + "," + privilege + "," + username + "," + cardnum + "," + multicard + "," + password + "," + issuetime + "," + expiretime);
                        }
                    } 
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnSetUser_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                { 
                    int userid = Convert.ToInt32(txtUserID.Text.Trim());
                    int privilege = Convert.ToInt32(txtPrivilege.Text.Trim());
                    string username = txtUserName.Text.Trim();
                    string cardnum = txtCardNum.Text.Trim();
                    int multicard = Convert.ToInt32(txtMulticardGroup.Text.Trim());
                    string password = txtPassword.Text.Trim();
                    string issuetime = Convert.ToDateTime(txtStartTime.Text.Trim()).ToString("yyyyMMdd");
                    string expiretime = Convert.ToDateTime(txtExpireTime.Text.Trim()).ToString("yyyyMMdd");
                     
                    sdk.SetUserInfo(userid, privilege, username, cardnum, multicard, password, issuetime, expiretime);
                    if (sdk.WriteAllDataToDevice())// upload user to Ingresuss  
                    {
                        ShowCurrentStatus("Successfully upload user");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to upload user");
                    } 
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDelUser_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                     int userid = Convert.ToInt32(txtUserID.Text.Trim());
                     if (sdk.DeleteUserInfo(userid))
                     { 
                         ShowCurrentStatus("Successfully delete userid=" + userid); 
                     }
                     else
                     {
                         ShowCurrentStatus("Failed to delete userid=" + userid); 
                     }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDelAllUser_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ClearUserInfo())
                    {
                        ShowCurrentStatus("Successfully clear user info");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to clear user info");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        #endregion

        #region User Access Level 
        private void btnGetAL_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadDeviceData(clsConst.TableName_Display_UserAccessLevel, txtUserID.Text.Trim()))
                    {
                        int userid = 0;
                        int timezoneid = 0;
                        int doorid = 0;

                        ShowCurrentStatus(clsConst.TableName_UserAccessLevel_Col);
                        //"UserID,AuthorizeTimezoneId,AuthorizeDoorId";

                        while (sdk.GetUserAccessLevel(out userid, out timezoneid, out doorid))
                        {
                            ShowCurrentStatus(userid + "," + timezoneid + "," + doorid);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnSetUserAL_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int userid = Convert.ToInt32(txtALUser.Text.Trim());
                    int timezoneid = Convert.ToInt32(txtALTimezone.Text.Trim());
                    int doorid = Convert.ToInt32(txtALDoor.Text.Trim());

                    sdk.SetUserAccessLevel(userid, timezoneid, doorid);
                    if (sdk.WriteAllDataToDevice())
                    {
                        ShowCurrentStatus("Successfully upload user access level");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to upload user access level");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDeleteUserAL_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int userid = Convert.ToInt32(txtALUser.Text.Trim()); 
                    if (sdk.DeleteUserAccessLevel(userid ))
                    {
                        ShowCurrentStatus("Successfully delete user access level");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete user access level");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnGetAllAL_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadAllDeviceData(clsConst.TableName_Display_UserAccessLevel))
                    {
                        int userid = 0;
                        int timezoneid = 0;
                        int doorid = 0;

                        ShowCurrentStatus(clsConst.TableName_UserAccessLevel_Col);
                        //"UserID,AuthorizeTimezoneId,AuthorizeDoorId";

                        while (sdk.GetUserAccessLevel(out userid, out timezoneid, out doorid))
                        {
                            ShowCurrentStatus(userid + "," + timezoneid + "," + doorid);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDeleteAllAL_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ClearUserAccessLevel())
                    {
                        ShowCurrentStatus("Successfully delete all user access level");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete all user access level");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }
        #endregion

        #region Holiday
        private void btnGetHoliday_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadDeviceData(clsConst.TableName_Display_Holiday, txtHoliday.Text.Trim()))
                    {
                        string holiday = string.Empty ;
                        int holidaytype = 0;
                        int loop = 0;

                        ShowCurrentStatus(clsConst.TableName_Holiday_Col);
                        //"Holiday,HolidayType,Loop";

                        while (sdk.GetHolidayData(out holiday, out holidaytype, out loop))
                        {
                            ShowCurrentStatus(holiday + "," + holidaytype + "," + loop);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnSetHoliday_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    string holiday = txtHoliday.Text.Trim();
                    int holidaytype =Convert.ToInt32(txtHolidayType.Text.Trim());
                    int loop = Convert.ToInt32(txtLoop.Text.Trim());

                    sdk.SetHolidayData(  holiday,   holidaytype,   loop); 
                    if (sdk.WriteAllDataToDevice())
                    {
                        ShowCurrentStatus("Successfully upload holiday"); 
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to upload holiday");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDeleteHoliday_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    string holiday = txtHoliday.Text.Trim(); 
                    if ( sdk.DeleteHolidayData(holiday ))
                    {
                        ShowCurrentStatus("Successfully delete holiday");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete holiday");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnGetAllHoliday_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadAllDeviceData(clsConst.TableName_Display_Holiday))
                    {
                        string holiday = string.Empty;
                        int holidaytype = 0;
                        int loop = 0;

                        ShowCurrentStatus(clsConst.TableName_Holiday_Col);
                        //"Holiday,HolidayType,Loop";

                        while (sdk.GetHolidayData(out holiday, out holidaytype, out loop))
                        {
                            ShowCurrentStatus(holiday + "," + holidaytype + "," + loop);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDelAllHoliday_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ClearHolidayData( ))
                    {
                        ShowCurrentStatus("Successfully delete all holiday");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete all holiday");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }
        #endregion

        #region Timezone
        private void btnGetTimezone_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadDeviceData(clsConst.TableName_Display_TimeZone, txtTimezoneID .Text.Trim()))
                    {
                        int TimezoneId = 0;
                        long SunTime1 = 0;
                        long SunTime2 = 0;
                        long SunTime3 = 0;
                        long MonTime1 = 0;
                        long MonTime2 = 0;
                        long MonTime3 = 0;
                        long TueTime1 = 0;
                        long TueTime2 = 0;
                        long TueTime3 = 0;
                        long WedTime1 = 0;
                        long WedTime2 = 0;
                        long WedTime3 = 0;
                        long ThuTime1 = 0;
                        long ThuTime2 = 0;
                        long ThuTime3 = 0;
                        long FriTime1 = 0;
                        long FriTime2 = 0;
                        long FriTime3 = 0;
                        long SatTime1 = 0;
                        long SatTime2 = 0;
                        long SatTime3 = 0;
                        long Hol1Time1 = 0;
                        long Hol1Time2 = 0;
                        long Hol1Time3 = 0;
                        long Hol2Time1 = 0;
                        long Hol2Time2 = 0;
                        long Hol2Time3 = 0;
                        long Hol3Time1 = 0;
                        long Hol3Time2 = 0;
                        long Hol3Time3 = 0;

                        ShowCurrentStatus(clsConst.TableName_TimeZone_Col);
                        //"TimezoneId,SunTime1,SunTime2,SunTime3,MonTime1,MonTime2,MonTime3,TueTime1,TueTime2,TueTime3,WedTime1,WedTime2,WedTime3,ThuTime1,ThuTime2,ThuTime3,FriTime1,FriTime2,FriTime3,SatTime1,SatTime2,SatTime3,Hol1Time1,Hol1Time2,Hol1Time3,Hol2Time1,Hol2Time2,Hol2Time3,Hol3Time1,Hol3Time2,Hol3Time3";

                        while (sdk.GetTimezoneData(out  TimezoneId, out  SunTime1, out  SunTime2, out  SunTime3,
                                   out  MonTime1, out  MonTime2, out  MonTime3, out  TueTime1, out  TueTime2, out  TueTime3,
                                   out  WedTime1, out  WedTime2, out  WedTime3, out  ThuTime1, out  ThuTime2, out  ThuTime3,
                                   out  FriTime1, out  FriTime2, out  FriTime3, out  SatTime1, out  SatTime2, out  SatTime3,
                                   out  Hol1Time1, out  Hol1Time2, out  Hol1Time3, out  Hol2Time1, out  Hol2Time2, out  Hol2Time3,
                                   out  Hol3Time1, out  Hol3Time2, out  Hol3Time3))
                        {
                            ShowCurrentStatus(TimezoneId+ "," + SunTime1+ "," + SunTime2+ "," + SunTime3+ "," + MonTime1+ "," + MonTime2+ "," + MonTime3+ "," + TueTime1+ "," + TueTime2+ "," + TueTime3+ "," + WedTime1+ "," + WedTime2+ "," + WedTime3+ "," + ThuTime1+ "," + ThuTime2+ "," + ThuTime3+ "," + FriTime1+ "," + FriTime2+ "," + FriTime3+ "," + SatTime1+ "," + SatTime2+ "," + SatTime3+ "," + Hol1Time1+ "," + Hol1Time2+ "," + Hol1Time3+ "," + Hol2Time1+ "," + Hol2Time2+ "," + Hol2Time3+ "," + Hol3Time1 + "," + Hol3Time2 + "," + Hol3Time3);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnSetTimezone_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                { 
                    int TimezoneId = Convert.ToInt32(txtTimezoneID.Text.Trim());
                    long SunTime1 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSun1S.Text.Trim() + txtSun1E.Text.Trim()); // starttime + endtime, must be 8digits
                    long SunTime2 =  clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSun2S.Text.Trim() + txtSun2E.Text.Trim());
                    long SunTime3 =  clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSun3S.Text.Trim() + txtSun3E.Text.Trim());
                    long MonTime1 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtMon1S.Text.Trim() + txtMon1E.Text.Trim());
                    long MonTime2 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtMon2S.Text.Trim() + txtMon2E.Text.Trim());
                    long MonTime3 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtMon3S.Text.Trim() + txtMon3E.Text.Trim());
                    long TueTime1 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtTue1S.Text.Trim() + txtTue1E.Text.Trim());
                    long TueTime2 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtTue2S.Text.Trim() + txtTue2E.Text.Trim());
                    long TueTime3 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtTue3S.Text.Trim() + txtTue3E.Text.Trim());
                    long WedTime1 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtWed1S.Text.Trim() + txtWed1E.Text.Trim());
                    long WedTime2 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtWed2S.Text.Trim() + txtWed2E.Text.Trim());
                    long WedTime3 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtWed3S.Text.Trim() + txtWed3E.Text.Trim());
                    long ThuTime1 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtThu1S.Text.Trim() + txtThu1E.Text.Trim());
                    long ThuTime2 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtThu2S.Text.Trim() + txtThu2E.Text.Trim());
                    long ThuTime3 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtThu3S.Text.Trim() + txtThu3E.Text.Trim());
                    long FriTime1 =  clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtFri1S.Text.Trim() + txtSun1E.Text.Trim());
                    long FriTime2 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtFri2S.Text.Trim() + txtFri2E.Text.Trim());
                    long FriTime3 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtFri3S.Text.Trim() + txtFri3E.Text.Trim());
                    long SatTime1 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSat1S.Text.Trim() + txtSat1E.Text.Trim());
                    long SatTime2 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSat2S.Text.Trim() + txtSat2E.Text.Trim());
                    long SatTime3 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtSat3S.Text.Trim() + txtSat3E.Text.Trim());
                    long Hol1Time1 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol11S.Text.Trim() + txtHol11E.Text.Trim());
                    long Hol1Time2 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol12S.Text.Trim() + txtHol12E.Text.Trim());
                    long Hol1Time3 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol13S.Text.Trim() + txtHol13E.Text.Trim());
                    long Hol2Time1 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol21S.Text.Trim() + txtHol21E.Text.Trim());
                    long Hol2Time2 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol22S.Text.Trim() + txtHol22E.Text.Trim());
                    long Hol2Time3 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol23S.Text.Trim() + txtHol23E.Text.Trim());
                    long Hol3Time1 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol31S.Text.Trim() + txtHol31E.Text.Trim());
                    long Hol3Time2 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol32S.Text.Trim() + txtHol32E.Text.Trim());
                    long Hol3Time3 = clsFuncs.ConvertTimezoneTimeFormat_ToDecimal(txtHol33S.Text.Trim() + txtHol33E.Text.Trim());

                  
                    sdk.SetTimezoneData(TimezoneId, SunTime1, SunTime2, SunTime3,
                                 MonTime1, MonTime2, MonTime3, TueTime1, TueTime2, TueTime3,
                                 WedTime1, WedTime2, WedTime3, ThuTime1, ThuTime2, ThuTime3,
                                 FriTime1, FriTime2, FriTime3, SatTime1, SatTime2, SatTime3,
                                 Hol1Time1, Hol1Time2, Hol1Time3, Hol2Time1, Hol2Time2, Hol2Time3,
                                 Hol3Time1, Hol3Time2, Hol3Time3);

                    if (sdk.WriteAllDataToDevice())
                    {
                        ShowCurrentStatus("Successfully upload timezone");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to upload timezone");
                    } 
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDeleteTimezone_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int TimezoneId = Convert.ToInt32(txtTimezoneID.Text.Trim());

                    if (sdk.DeleteTimezoneData(TimezoneId))
                    {
                        ShowCurrentStatus("Successfully delete timezone");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete timezone");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnGetAllTimezone_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadAllDeviceData(clsConst.TableName_Display_TimeZone))
                    {

                        int TimezoneId = 0;
                        long SunTime1 = 0;
                        long SunTime2 = 0;
                        long SunTime3 = 0;
                        long MonTime1 = 0;
                        long MonTime2 = 0;
                        long MonTime3 = 0;
                        long TueTime1 = 0;
                        long TueTime2 = 0;
                        long TueTime3 = 0;
                        long WedTime1 = 0;
                        long WedTime2 = 0;
                        long WedTime3 = 0;
                        long ThuTime1 = 0;
                        long ThuTime2 = 0;
                        long ThuTime3 = 0;
                        long FriTime1 = 0;
                        long FriTime2 = 0;
                        long FriTime3 = 0;
                        long SatTime1 = 0;
                        long SatTime2 = 0;
                        long SatTime3 = 0;
                        long Hol1Time1 = 0;
                        long Hol1Time2 = 0;
                        long Hol1Time3 = 0;
                        long Hol2Time1 = 0;
                        long Hol2Time2 = 0;
                        long Hol2Time3 = 0;
                        long Hol3Time1 = 0;
                        long Hol3Time2 = 0;
                        long Hol3Time3 = 0;

                        ShowCurrentStatus(clsConst.TableName_TimeZone_Col);

                        while (sdk.GetTimezoneData(out  TimezoneId, out  SunTime1, out  SunTime2, out  SunTime3,
                                        out  MonTime1, out  MonTime2, out  MonTime3, out  TueTime1, out  TueTime2, out  TueTime3,
                                        out  WedTime1, out  WedTime2, out  WedTime3, out  ThuTime1, out  ThuTime2, out  ThuTime3,
                                        out  FriTime1, out  FriTime2, out  FriTime3, out  SatTime1, out  SatTime2, out  SatTime3,
                                        out  Hol1Time1, out  Hol1Time2, out  Hol1Time3, out  Hol2Time1, out  Hol2Time2, out  Hol2Time3,
                                        out  Hol3Time1, out  Hol3Time2, out  Hol3Time3))
                        {
                            ShowCurrentStatus(TimezoneId + "," + SunTime1 + "," + SunTime2 + "," + SunTime3 + "," + MonTime1 + "," + MonTime2 + "," + MonTime3 + "," + TueTime1 + "," + TueTime2 + "," + TueTime3 + "," + WedTime1 + "," + WedTime2 + "," + WedTime3 + "," + ThuTime1 + "," + ThuTime2 + "," + ThuTime3 + "," + FriTime1 + "," + FriTime2 + "," + FriTime3 + "," + SatTime1 + "," + SatTime2 + "," + SatTime3 + "," + Hol1Time1 + "," + Hol1Time2 + "," + Hol1Time3 + "," + Hol2Time1 + "," + Hol2Time2 + "," + Hol2Time3 + "," + Hol3Time1 + "," + Hol3Time2 + "," + Hol3Time3);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found");
                    } 
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDeleteAllTimezone_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                { 
                    if (sdk.ClearTimezoneData())
                    {
                        ShowCurrentStatus("Successfully clear all timezone");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to clear all timezone");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }
        #endregion

        #region General Log
        private void btnGetGeneral_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadDeviceData(clsConst.TableName_Display_GeneralLog, txtGUser.Text.Trim()))
                    {
                        int userid = 0;
                        string cardNumber = string.Empty;
                        int verified = 0;
                        int doorNo = 0;
                        int eventType = 0;
                        int inOutState = 0;
                        int timesec = 0;

                        ShowCurrentStatus(clsConst.TableName_GeneralLog_Col);
                        // "UserID,Cardno,Verified,DoorNo,EventType,InOutState,Time_second";

                        while (sdk.GetUserGeneralLog(out userid, out cardNumber, out verified, out doorNo, out eventType, out inOutState, out timesec))
                        {
                            ShowCurrentStatus(userid + "," + cardNumber + "," + verified + "," + doorNo + "," + eventType + "," + inOutState + "," + timesec);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnSetGeneral_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int userid = Convert.ToInt32(txtGUser.Text.Trim());
                    string cardNumber = txtGCard.Text.Trim();
                    int verified =Convert.ToInt32(txtGDoor.Text.Trim());
                    int doorNo = Convert.ToInt32(txtGDoor.Text.Trim());
                    int eventType = Convert.ToInt32(txtGEvent.Text.Trim());
                    int inOutState = Convert.ToInt32(txtGInOut.Text.Trim());


                    int iYear = Convert.ToInt32(txtGYear.Text.Trim());
                    int iMonth = Convert.ToInt32(txtGMonth.Text.Trim());
                    int iDay = Convert.ToInt32(txtGDay.Text.Trim());
                    int iHour = Convert.ToInt32(txtGHour.Text.Trim());
                    int iMinute = Convert.ToInt32(txtGMinute.Text.Trim());
                    int iSec = Convert.ToInt32(txtGSecond.Text.Trim()); 
                    int timesec = ((iYear - 2000) * 12 * 31 + (iMonth - 1) * 31 + (iDay - 1)) * (24 * 60 * 60) + iHour * 60 * 60 + iMinute * 60 + iSec;
                     
                    sdk.SetUserGeneralLog(userid, cardNumber, verified, doorNo, eventType, inOutState, timesec);
                    if (sdk.WriteAllDataToDevice())
                    {
                        ShowCurrentStatus("Successfully upload general log");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to upload general log");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDeleteGeneral_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int userid = Convert.ToInt32(txtGUser.Text.Trim());
                    if (sdk.DeleteUserGeneralLog(userid ))
                    {
                        ShowCurrentStatus("Successfully delete general log");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete general log");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnGetAllGeneral_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadAllDeviceData(clsConst.TableName_Display_GeneralLog))
                    {
                        int userid = 0;
                        string cardNumber = string.Empty;
                        int verified = 0;
                        int doorNo = 0;
                        int eventType = 0;
                        int inOutState = 0;
                        int timesec = 0;

                        ShowCurrentStatus(clsConst.TableName_GeneralLog_Col);
                        // "UserID,Cardno,Verified,DoorNo,EventType,InOutState,Time_second";

                        while (sdk.GetUserGeneralLog(out userid, out cardNumber, out verified, out doorNo, out eventType, out inOutState, out timesec))
                        {
                            ShowCurrentStatus(userid + "," + cardNumber + "," + verified + "," + doorNo + "," + eventType + "," + inOutState + "," + timesec);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDeleteAllGeneral_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ClearUserGeneralLog())
                    {
                        ShowCurrentStatus("Successfully delete all general log");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete all general log");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }
        #endregion

        #region First Card
        private void btnGetFirst_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadDeviceData(clsConst.TableName_Display_FirstCard,txtFirstUser.Text.Trim()))
                    {
                        int userid = 0; 
                        int timezoneid = 0;
                        int doorNo = 0; 

                        ShowCurrentStatus(clsConst.TableName_FirstCard_Col);
                        //"UserID,DoorNo,TimezoneID";

                        while (sdk.GetFirstCardData(out userid,out doorNo,out timezoneid))
                        {
                            ShowCurrentStatus(userid + "," + doorNo + "," + timezoneid );
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnSetFirst_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int userid = Convert.ToInt32(txtFirstUser.Text.Trim());
                    int doorNo = Convert.ToInt32(txtFirstDoor.Text.Trim());
                    int timezoneid = Convert.ToInt32(txtFirstTimezone .Text.Trim());

                    sdk.SetFirstCardData(userid, doorNo, timezoneid);
                    if (sdk.WriteAllDataToDevice())
                    {
                        ShowCurrentStatus("Successfully upload First Card");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to upload First Card");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDelFirst_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int userid = Convert.ToInt32(txtFirstUser.Text.Trim());

                    if (sdk.DeleteFirstCardData (userid ))
                    {
                        ShowCurrentStatus("Successfully delete first card user");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete first card user");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnGetAllFirst_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadAllDeviceData(clsConst.TableName_Display_FirstCard))
                    {
                        int userid = 0;
                        int timezoneid = 0;
                        int doorNo = 0;

                        ShowCurrentStatus(clsConst.TableName_FirstCard_Col);
                        //"UserID,DoorNo,TimezoneID";

                        while (sdk.GetFirstCardData(out userid, out doorNo, out timezoneid))
                        {
                            ShowCurrentStatus(userid + "," + doorNo + "," + timezoneid);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDelAllFirst_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                { 
                    if (sdk.ClearFirstCardData())
                    {
                        ShowCurrentStatus("Successfully delete all first card user");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete all first card user");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        #endregion

        #region Multicard
        private void btnGetMulti_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadDeviceData(clsConst.TableName_Display_MultiCard,txtMIndex.Text.Trim()))
                    {
                        int index = 0;
                        int doorNo = 0;
                        int g1 = 0;
                        int g2 = 0;
                        int g3 = 0;
                        int g4 = 0;
                        int g5 = 0;

                        ShowCurrentStatus(clsConst.TableName_MultiCard_Col);
                        // "Index,DoorId,Group1,Group2,Group3,Group4,Group5";

                        while (sdk.GetMultiCardData(out index, out doorNo, out g1, out g2, out g3, out g4, out g5))
                        {
                            ShowCurrentStatus(index + "," + doorNo + "," + g1 + "," + g2 + "," + g3 + "," + g4 + "," + g5);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnSetMulti_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                { 
                    int index = Convert.ToInt32(txtMIndex.Text.Trim());
                    int doorNo = Convert.ToInt32(txtMDoor.Text.Trim());
                    int g1 = Convert.ToInt32(txtMP1 .Text.Trim());
                    int g2 = Convert.ToInt32(txtMP2.Text.Trim());
                    int g3 = Convert.ToInt32(txtMP3.Text.Trim());
                    int g4 = Convert.ToInt32(txtMP4.Text.Trim());
                    int g5 = Convert.ToInt32(txtMP5.Text.Trim());

                    sdk.SetMultiCardData(index, doorNo, g1, g2, g3, g4, g5);
                    if (sdk.WriteAllDataToDevice())
                    {
                        ShowCurrentStatus("Successfully upload multicard");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to upload multicard");
                    } 
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDeleteMulti_Click(object sender, EventArgs e)
        {
            try
             {
                if (IsDeviceConnected())
                { 
                    int index = Convert.ToInt32(txtMIndex.Text.Trim()); 

                    if ( sdk.DeleteMultiCardData(index  ))
                    {
                        ShowCurrentStatus("Successfully delete multicard");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete multicard");
                    } 
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnGetAllMulti_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadAllDeviceData(clsConst.TableName_Display_MultiCard ))
                    {
                        int index = 0;
                        int doorNo = 0;
                        int g1 = 0;
                        int g2 = 0;
                        int g3 = 0;
                        int g4 = 0;
                        int g5 = 0;

                        ShowCurrentStatus(clsConst.TableName_MultiCard_Col);
                        // "Index,DoorId,Group1,Group2,Group3,Group4,Group5";

                        while (sdk.GetMultiCardData(out index, out doorNo, out g1, out g2, out g3, out g4, out g5))
                        {
                            ShowCurrentStatus(index + "," + doorNo + "," + g1 + "," + g2 + "," + g3 + "," + g4 + "," + g5);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDelAllMulti_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                { 
                    if (sdk.ClearMultiCardData( ))
                    {
                        ShowCurrentStatus("Successfully delete all multicard");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete all multicard");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }
        #endregion

        #region Fire Alarm
        private void btnGetLinkage_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadDeviceData(clsConst.TableName_Display_FireAlarm,txtLinkageIndex.Text.Trim()))
                    {
                        int index = 0;
                        int eventType = 0;
                        int InAddr = 0;
                        int OutType = 0;
                        int OutAddr = 0;
                        int OutTime = 0;

                        ShowCurrentStatus(clsConst.TableName_FireAlarm_Col);
                        //"Index,EventType,InAddr,OutType,OutAddr,OutTime";

                        while (sdk.GetFireAlarmData(out index, out eventType, out InAddr, out OutType, out OutAddr, out OutTime ))
                        {
                            ShowCurrentStatus(index + "," + eventType + "," + InAddr + "," + OutType + "," + OutAddr + "," + OutTime );
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnSetLinkage_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int index = Convert.ToInt32(txtLinkageIndex.Text.Trim());
                    int eventType = Convert.ToInt32(txtLinkageEvent  .Text.Trim());
                    int InAddr = Convert.ToInt32(txtLinkageInAdd   .Text.Trim());
                    int OutType = Convert.ToInt32(txtLinkageOutType .Text.Trim());
                    int OutAddr = Convert.ToInt32(txtLinkageOutAdd  .Text.Trim());
                    int OutTime = Convert.ToInt32(txtLinkageOutTime  .Text.Trim());

                    sdk.SetFireAlarmData(index, eventType, InAddr, OutType, OutAddr, OutTime );
                    if (sdk.WriteAllDataToDevice())
                    {
                        ShowCurrentStatus("Successfully upload fire alarm");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to upload fire alarm");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDelLinkage_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int index = Convert.ToInt32(txtLinkageIndex.Text.Trim()); 

                    if (sdk.DeleteFireAlarmData(index))
                    {
                        ShowCurrentStatus("Successfully delete fire alarm");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete fire alarm");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnGetAllLinkage_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadAllDeviceData(clsConst.TableName_Display_FireAlarm ))
                    {
                        int index = 0;
                        int eventType = 0;
                        int InAddr = 0;
                        int OutType = 0;
                        int OutAddr = 0;
                        int OutTime = 0;

                        ShowCurrentStatus(clsConst.TableName_FireAlarm_Col);
                        //"Index,EventType,InAddr,OutType,OutAddr,OutTime";

                        while (sdk.GetFireAlarmData(out index, out eventType, out InAddr, out OutType, out OutAddr, out OutTime))
                        {
                            ShowCurrentStatus(index + "," + eventType + "," + InAddr + "," + OutType + "," + OutAddr + "," + OutTime);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDelAllLinkage_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                { 
                    if (sdk.ClearFireAlarmData())
                    {
                        ShowCurrentStatus("Successfully delete all fire alarm");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete all fire alarm");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }
        #endregion

        #region Template
        private void btnGetTemp_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadDeviceData(clsConst.TableName_Display_Template,txtTemplateUser.Text.Trim()))
                    {
                        int userid = 0;
                        int fingerid = 0;
                        int valid = 0;
                        string template = string.Empty;

                        ShowCurrentStatus(clsConst.TableName_Template_Col);
                        // "UserID,FingerID,Valid,Template";

                        while (sdk.GetUserTemplate(out userid, out fingerid, out valid, out template ))
                        {
                            ShowCurrentStatus(userid + "," + fingerid + "," + valid + "," + template );
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnSetTemp_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                { 
                    int userid = Convert.ToInt32(txtTemplateUser.Text.Trim());
                    int fingerid = Convert.ToInt32(txtTemplateFinger.Text.Trim());
                    int valid = Convert.ToInt32(txtTempValid.Text.Trim());
                    string template = txtTemplate.Text.Trim();

                    sdk.SetUserTemplate(userid, fingerid, valid, template);
                    if (sdk.WriteAllDataToDevice())
                    {
                        ShowCurrentStatus("Successfully upload user template");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to upload user template");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDelTemp_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int userid = Convert.ToInt32(txtTemplateUser.Text.Trim()); 

                    if (sdk .DeleteUserTemplate(userid))
                    {
                        ShowCurrentStatus("Successfully delete user template");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete user template");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnGetAllTemp_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (sdk.ReadAllDeviceData(clsConst.TableName_Display_Template ))
                    {
                        int userid = 0;
                        int fingerid = 0;
                        int valid = 0;
                        string template = string.Empty;

                        ShowCurrentStatus(clsConst.TableName_Template_Col);
                        // "UserID,FingerID,Valid,Template";

                        while (sdk.GetUserTemplate(out userid, out fingerid, out valid, out template))
                        {
                            ShowCurrentStatus(userid + "," + fingerid + "," + valid + "," + template);
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("No record found.");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDelAllTemp_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                { 
                    if (sdk.ClearUserTemplate())
                    {
                        ShowCurrentStatus("Successfully delete all user template");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to delete all user template");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }
        #endregion

        #region Scan Device
        List<ObjDevice> listDevice = new List<ObjDevice>();
        private void btnScanDevice_Click(object sender, EventArgs e)
        {
            try
            {
                this.Cursor = Cursors.WaitCursor;
                using (Ingressus.Ingressus sdkScan = new Ingressus.Ingressus()) // after scan, dispose the object
                {
                    ShowCurrentStatus("Scanning network...");

                    if (sdkScan.ScanDevice())
                    {
                        string mac = string.Empty;
                        string serialNo = string.Empty;
                        string ip = string.Empty;
                        string gateway = string.Empty;
                        string subnet = string.Empty;
                        string firmVer = string.Empty;
                        string model = string.Empty;

                        while (sdkScan.GetScanDevice(out mac, out serialNo, out ip, out gateway, out subnet, out firmVer, out model))
                        {
                            listDevice.Add(new ObjDevice { MAC = mac, IPAddress = ip, Firmware = firmVer, Gateway = gateway, Model = model, SerialNum = serialNo, Subnet = subnet });

                        }

                        AddDeviceToDropDownList();
                        ShowCurrentStatus("Successfully scan network");
                    }
                    else
                    {
                        ShowCurrentStatus("No Ingressus found.");
                    }

                    if (cboMAC.Items.Count > 0)
                    {
                        txtNewGateway.Enabled = true;
                        txtNewIP.Enabled = true;
                        txtNewSubnet.Enabled = true;
                        cboMAC.Enabled = true;
                        btnChangeDevice.Enabled = true;
                    }
                    else
                    {
                        txtNewGateway.Enabled = false;
                        txtNewIP.Enabled = false;
                        txtNewSubnet.Enabled = false;
                        cboMAC.Enabled = false;
                        btnChangeDevice.Enabled = false;
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
            this.Cursor = Cursors.Arrow ;
        }

        protected void AddDeviceToDropDownList()
        {
            foreach (ObjDevice device in listDevice)
            {
                cboMAC.Items.Add(device.MAC   + " ( " + device.SerialNum + " )");
            } 
        }

        private void cboMAC_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                if (cboMAC.SelectedItem != null && cboMAC.SelectedItem.ToString() != string.Empty)
                {
                    string selectedIngressus = cboMAC.SelectedItem.ToString();
                    string[] split = selectedIngressus.Split('(');
                    string mac = split[0].Trim();

                    foreach (ObjDevice device in listDevice)
                    {
                        if (device.MAC == mac)
                        {
                            txtNewGateway.Text = device.Gateway ;
                            txtNewSubnet.Text = device.Subnet;
                            txtNewIP.Text = device.IPAddress;
                            break;
                        }
                    }
                }  
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnChangeDevice_Click(object sender, EventArgs e)
        {
            try
            {
                if (cboMAC.SelectedItem != null && cboMAC.SelectedItem.ToString() != string.Empty)
                {
                    string selectedIngressus = cboMAC.SelectedItem.ToString();
                    string[] split = selectedIngressus.Split('(');
                    string mac = split[0].Trim();

                    if (!string.IsNullOrEmpty(mac))
                    {
                        using (Ingressus.Ingressus sdkChange = new Ingressus.Ingressus())
                        {
                            if (sdkChange.ChangeDeviceInfo(mac, txtNewIP.Text.Trim(), txtNewGateway.Text.Trim(), txtNewSubnet.Text.Trim()))
                            {
                                ShowCurrentStatus("Successfully change device info");
                            }
                            else
                            {
                                ShowCurrentStatus("Failed to change device info");
                            }
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to change device info");
                    }
                }
                else
                {
                    ShowCurrentStatus("Please select choose a Ingressus");
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }
        #endregion

        #region Ingressus Options
        private void btnSysGet_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (cboSysP.SelectedItem != null && cboSysP.SelectedItem.ToString() != string.Empty)
                    {
                        string value = sdk.GetSysOptions(cboSysP.SelectedItem.ToString().Trim());
                        txtSysV.Text = value;
                        ShowCurrentStatus(cboSysP.SelectedItem.ToString() + "=" + value);
                    }
                    else
                    {
                        ShowCurrentStatus("Please select a system options");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); } 
        }

        private void btnSysSet_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (cboSysP.SelectedItem != null && cboSysP.SelectedItem.ToString() != string.Empty)
                    {
                        if (sdk.SetSysOptions(cboSysP.SelectedItem.ToString().Trim(), txtSysV.Text.Trim()))
                        {
                            ShowCurrentStatus("Successfully set system options");
                        }
                        else
                        {
                            ShowCurrentStatus("Failed to set system options");
                        }
                    }
                    else
                    {
                        ShowCurrentStatus("Please select a system options");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDoorGet_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (IsDeviceConnected())
                    {
                        if (cboDoorP.SelectedItem != null && cboDoorP.SelectedItem.ToString() != string.Empty)
                        {
                            int doorNo = Convert.ToInt32(txtDoorDNo.Text.Trim());
                            string value = sdk.GetDoorOptions(doorNo, cboDoorP.SelectedItem.ToString().Trim());
                            txtDoorV.Text = value;
                            ShowCurrentStatus(cboDoorP.SelectedItem.ToString().Trim() + "=" + value);
                        }
                        else
                        {
                            ShowCurrentStatus("Please select a door options");
                        }
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnDoorSet_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (IsDeviceConnected())
                    {
                        if (cboDoorP.SelectedItem != null && cboDoorP.SelectedItem.ToString() != string.Empty)
                        {
                            int doorNo = Convert.ToInt32(txtDoorDNo.Text.Trim());
                            if (sdk.SetDoorOptions(doorNo, cboDoorP.SelectedItem.ToString().Trim(), txtDoorV.Text.Trim()))
                            {
                                ShowCurrentStatus("Successfully set door options");
                            }
                            else
                            {
                                ShowCurrentStatus("Failed to set door options");
                            }
                        }
                        else
                        {
                            ShowCurrentStatus("Please select a door options");
                        }
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnSetLocalTime_Click(object sender, EventArgs e)
        {
            if (IsDeviceConnected())
            {
                if (sdk.SetDeviceTimeLocal())
                {
                    ShowCurrentStatus("Successfully set device date and time");
                }
                else
                {
                    ShowCurrentStatus("Failed to set device date and time");
                }
            }
        }

        private void btnSetTime_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int iYear = Convert.ToInt32(txtOptYear.Text.Trim());
                    int iMonth = Convert.ToInt32(txtOptMonth.Text.Trim());
                    int iDay = Convert.ToInt32(txtOptDay.Text.Trim());
                    int iHour = Convert.ToInt32(txtOptHour.Text.Trim());
                    int iMinute = Convert.ToInt32(txtOptMin.Text.Trim());
                    int iSec = Convert.ToInt32(txtOptSec.Text.Trim());

                    if (sdk.SetDeviceTime(iYear, iMonth, iDay, iHour, iMinute, iSec))
                    {
                        ShowCurrentStatus("Successfully set device date and time");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to set device date and time");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnGetDeviceTime_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    string deviceTime = sdk.GetSysOptions("DateTime");
                    long iDeviceTime = Convert.ToInt64(deviceTime);
                    long Second = iDeviceTime % 60;
                    long Minute = (iDeviceTime / 60) % 60;
                    long Hour = (iDeviceTime / 3600) % 24;
                    long Day = (iDeviceTime / 86400) % 31 + 1;
                    long Month = (iDeviceTime / 2678400) % 12 + 1;
                    long Year = (iDeviceTime / 32140800) + 2000;

                    ShowCurrentStatus("Device Current Time : " + Year + "-" + Month + "-" + Day + " " + Hour + ":" + Minute + ":" + Second);
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); } 
        }


        #region Remote Options
        private void btnRemoteClose_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    int doorNo = Convert.ToInt32(txtRemoteDoor.Text.Trim());

                    if (sdk.RemoteCloseDoor(doorNo))
                    {
                        ShowCurrentStatus("Successfully close door");
                    }
                    else
                    {
                        ShowCurrentStatus("Failed to open door");
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnRemoteOpen_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (IsDeviceConnected())
                    {
                        int doorNo = Convert.ToInt32(txtRemoteDoor.Text.Trim());

                        if (sdk.RemoteOpenDoor(doorNo, 10)) // open for 10 sec, range 1 ~ 60 sec
                        {
                            ShowCurrentStatus("Successfully open door");
                        }
                        else
                        {
                            ShowCurrentStatus("Failed to open door");
                        }
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); }
        }

        private void btnRestart_Click(object sender, EventArgs e)
        {
            if (IsDeviceConnected())
            {
                if (sdk.RestartDevice())
                {
                    ShowCurrentStatus("Successfully restart Ingressus");
                }
                else
                {
                    ShowCurrentStatus("Failed to restart Ingressus");
                }
            }
        }

        private void btnOffAlarm_Click(object sender, EventArgs e)
        {
            if (IsDeviceConnected())
            {
                if (sdk.TurnOffAlarm())
                {
                    ShowCurrentStatus("Successfully turn off alarm");
                }
                else
                {
                    ShowCurrentStatus("Failed to turn off alarm");
                }
            }
        }

        private void btnRemoteCloseNormal_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (IsDeviceConnected())
                    {
                        int doorNo = Convert.ToInt32(txtRemoteDoor.Text.Trim());

                        if (sdk.RemoteNormalCloseDoor(doorNo)) // open for 10 sec, range 1 ~ 60 sec
                        {
                            ShowCurrentStatus("Successfully open door");
                        }
                        else
                        {
                            ShowCurrentStatus("Failed to open door");
                        }
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); } 
        }

        private void btnRemoteOpenNormal_Click(object sender, EventArgs e)
        {
            try
            {
                if (IsDeviceConnected())
                {
                    if (IsDeviceConnected())
                    {
                        int doorNo = Convert.ToInt32(txtRemoteDoor.Text.Trim());

                        if (sdk.RemoteNormalOpenDoor (doorNo)) 
                        {
                            ShowCurrentStatus("Successfully open door");
                        }
                        else
                        {
                            ShowCurrentStatus("Failed to open door");
                        }
                    }
                }
            }
            catch (Exception ex) { ShowCurrentStatus(ex.Message); } 
        }
        #endregion
        #endregion
         
        private void txtTemplate_KeyDown(object sender, KeyEventArgs e)
        {
            try
            {
                if (e.Control && (e.KeyCode == System.Windows.Forms.Keys.A))
                {
                    txtTemplate.SelectAll();
                    e.SuppressKeyPress = true;
                    e.Handled = true;
                }
                else
                    base.OnKeyDown(e);
            }
            catch { }
        }

    
     

       

       
    }

    public class ObjDevice
    {
        public string MAC { get; set; }
        public string SerialNum { get; set; }
        public string IPAddress { get; set; }
        public string Gateway { get; set; }
        public string Subnet { get; set; }
        public string Firmware { get; set; }
        public string Model { get; set; } 
    }


}
